rulebase.rules.sentence\_segmentation package
=============================================

Submodules
----------

.. toctree::

   rulebase.rules.sentence_segmentation.const
   rulebase.rules.sentence_segmentation.sentence_segmenter

Module contents
---------------

.. automodule:: rulebase.rules.sentence_segmentation
    :members:
    :undoc-members:
    :show-inheritance:
